@@ -23,7 +23,7 @@ Implementation Notes
 
 """
 
-__version__ = "2.22.10"
+__version__ = "2.22.12"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Text.git"
 
 import displayio
@@ -55,8 +55,9 @@ class Label(LabelBase):
       Must include a capital M for measuring character size.
     :type font: ~FontProtocol
     :param str text: Text to display
-    :param int color: Color of all text in RGB hex
-    :param int background_color: Color of the background, use `None` for transparent
+    :param int|Tuple(int, int, int) color: Color of all text in HEX or RGB
+    :param int|Tuple(int, int, int)|None background_color: Color of the background, use `None`
+     for transparent
     :param float line_spacing: Line spacing of text to display
     :param bool background_tight: Set `True` only if you want background box to tightly
      surround text. When set to 'True' Padding parameters will be ignored.
@@ -64,17 +65,17 @@ class Label(LabelBase):
     :param int padding_bottom: Additional pixels added to background bounding box at bottom
     :param int padding_left: Additional pixels added to background bounding box at left
     :param int padding_right: Additional pixels added to background bounding box at right
-    :param (float,float) anchor_point: Point that anchored_position moves relative to.
+    :param Tuple(float, float) anchor_point: Point that anchored_position moves relative to.
      Tuple with decimal percentage of width and height.
      (E.g. (0,0) is top left, (1.0, 0.5): is middle right.)
-    :param (int,int) anchored_position: Position relative to the anchor_point. Tuple
+    :param Tuple(int, int) anchored_position: Position relative to the anchor_point. Tuple
      containing x,y pixel coordinates.
     :param int scale: Integer value of the pixel scaling
     :param bool save_text: Set True to save the text string as a constant in the
      label structure.  Set False to reduce memory use.
     :param bool base_alignment: when True allows to align text label to the baseline.
      This is helpful when two or more labels need to be aligned to the same baseline
-    :param (int,str) tab_replacement: tuple with tab character replace information. When
+    :param Tuple(int, str) tab_replacement: tuple with tab character replace information. When
      (4, " ") will indicate a tab replacement of 4 spaces, defaults to 4 spaces by
      tab character
     :param str label_direction: string defining the label text orientation. There are 5
@@ -547,9 +548,12 @@ class Label(LabelBase):
             self._palette.make_transparent(0)
 
     def _set_label_direction(self, new_label_direction: str) -> None:
-        self._prev_label_direction = self._label_direction
-        self._label_direction = new_label_direction
-        self._reset_text(text=str(self._text))  # Force a recalculation
+        # Only make changes if new direction is different
+        # to prevent errors in the _reset_text() direction checks
+        if self._label_direction != new_label_direction:
+            self._prev_label_direction = self._label_direction
+            self._label_direction = new_label_direction
+            self._reset_text(text=str(self._text))  # Force a recalculation
 
     def _get_valid_label_directions(self) -> Tuple[str, ...]:
         return "LTR", "RTL", "UPD", "UPR", "DWR"
